from .exceptions import CapmonsterException
from .ImageToTextTask import ImageToTextTask
from .NoCaptchaTaskProxyless import NoCaptchaTaskProxyless
from .RecaptchaV3TaskProxyless import RecaptchaV3TaskProxyless
from .FunCaptchaTask import FunCaptchaTask
from .FunCaptchaTaskProxyless import FunCaptchaTaskProxyless
from .NoCaptchaTask import NoCaptchaTask
